| diagn_plot | R Documentation |
Plot convergence of best/median/mean/other summary log posteriors in time
diagn_plot(
res,
FUN = median,
conf = 0.95,
burnin = 0,
window = 5,
ylim = NULL,
...
)
res |
Object corresponding gmjmcmc output |
FUN |
The summary statistics to check convergence |
conf |
Which confidence intervals to plot |
burnin |
How many first populations to skip |
window |
Sliding window for computing the standard deviation |
ylim |
Limits for the plotting range; if unspecified, min and max of confidence intervals will be used |
... |
Additional graphical parameters passed to plot and lines functions, e.g. col, lwd, lty, main, xlab, ylab, ylim |
A list of summary statistics for checking convergence with given confidence intervals
result <- gmjmcmc(y = matrix(rnorm(100), 100),
x = matrix(rnorm(600), 100),
P = 2,
transforms = c("p0", "exp_dbl"))
diagnstats <- diagn_plot(result)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.