| gmjmcmc.parallel | R Documentation |
Run multiple gmjmcmc (Genetically Modified MJMCMC) runs in parallel returning a list of all results.
gmjmcmc.parallel(
x,
y,
loglik.pi = NULL,
mlpost_params = list(family = "gaussian", beta_prior = list(type = "g-prior")),
loglik.alpha = gaussian.loglik.alpha,
transforms,
runs = 2,
cores = getOption("mc.cores", 2L),
verbose = FALSE,
merge.options = list(populations = "best", complex.measure = 2, tol = 1e-07),
...
)
x |
matrix containing the design matrix with data to use in the algorithm |
y |
response variable |
loglik.pi |
The (log) density to explore |
mlpost_params |
parameters for the estimator function loglik.pi |
loglik.alpha |
The likelihood function to use for alpha calculation |
transforms |
A Character vector including the names of the non-linear functions to be used by the modification |
runs |
The number of runs to run |
cores |
The number of cores to run on |
verbose |
A logical denoting if messages should be printed |
merge.options |
A list of options to pass to the |
... |
Further parameters passed to mjmcmc. |
Results from multiple gmjmcmc runs
result <- gmjmcmc.parallel(
runs = 1,
cores = 1,
loglik.pi = NULL,
y = matrix(rnorm(100), 100),
x = matrix(rnorm(600), 100),
transforms = c("p0", "exp_dbl")
)
summary(result)
plot(result)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.