log_prior: Log model prior function

log_priorR Documentation

Log model prior function

Description

Log model prior function

Usage

log_prior(mlpost_params, complex)

Arguments

mlpost_params

list of passed parameters of the likelihood in GMJMCMC

complex

list of complexity measures of the features included into the model

Value

A numeric with the log model prior.

Examples

log_prior(mlpost_params = list(r=2), complex = list(oc = 2))


FBMS documentation built on Sept. 13, 2025, 1:09 a.m.