| model.string | R Documentation |
Function to generate a function string for a model consisting of features
model.string(model, features, link = "I", round = 2)
model |
A logical vector indicating which features to include |
features |
The population of features |
link |
The link function to use, as a string |
round |
Rounding error for the features in the printed format |
A character representation of a model
result <- gmjmcmc(y = matrix(rnorm(100), 100),
x = matrix(rnorm(600), 100),
P = 2, transforms = c("p0", "exp_dbl"))
summary(result)
plot(result)
model.string(c(TRUE, FALSE, TRUE, FALSE, TRUE), result$populations[[1]])
model.string(result$models[[1]][1][[1]]$model, result$populations[[1]])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.