Learn R Programming

FBMS (version 1.4)

plot.gmjmcmc: Function to Plot GMJMCMC Results and Merged Results from merge.results

Description

Function to Plot GMJMCMC Results and Merged Results from merge.results

Usage

# S3 method for gmjmcmc
plot(x, count = "all", pop = "best", tol = 1e-07, data = NULL, ...)

Value

No return value, just creates a plot

Arguments

x

The results to use

count

The number of features to plot, defaults to all

pop

The population to plot, can be "last", "best" or "highest_mass". Defaults to "best".

tol

The tolerance to use for the correlation when finding equivalent features, default is 0.0000001

data

Data to merge on, important if pre-filtering was used

...

Not used.

Examples

Run this code
result <- gmjmcmc(
  y = matrix(rnorm(100), 100),
  x = matrix(rnorm(600), 100),
  P = 2,
  transforms = c("p0", "exp_dbl")
)
plot(result)

Run the code above in your browser using DataLab