| plot.mjmcmc | R Documentation |
Function to plot the results, works both for results from gmjmcmc and merged results from merge.results
## S3 method for class 'mjmcmc'
plot(x, count = "all", ...)
x |
The results to use |
count |
The number of features to plot, defaults to all |
... |
Not used. |
No return value, just creates a plot
result <- mjmcmc(
y = matrix(rnorm(100), 100),
x = matrix(rnorm(600), 100),
loglik.pi = gaussian.loglik)
plot(result)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.