predict.mjmcmc: Predict using a mjmcmc result object.

predict.mjmcmcR Documentation

Predict using a mjmcmc result object.

Description

Predict using a mjmcmc result object.

Usage

## S3 method for class 'mjmcmc'
predict(
  object,
  x,
  link = function(x) x,
  quantiles = c(0.025, 0.5, 0.975),
  x_train = NULL,
  ...
)

Arguments

object

The model to use.

x

The new data to use for the prediction, a matrix where each row is an observation.

link

The link function to use

quantiles

The quantiles to calculate credible intervals for the posterior modes (in model space).

x_train

Training design matrix to be provided when imputations are to be made from them

...

Not used.

Value

A list containing aggregated predictions.

mean

Mean of aggregated predictions.

quantiles

Quantiles of aggregated predictions.

Examples

result <- mjmcmc(
x = matrix(rnorm(600), 100),
y = matrix(rnorm(100), 100),
loglik.pi = gaussian.loglik)
preds <- predict(result, matrix(rnorm(600), 100))


FBMS documentation built on Sept. 13, 2025, 1:09 a.m.