| print.feature | R Documentation |
Print method for "feature" class
## S3 method for class 'feature'
print(
x,
dataset = FALSE,
fixed = 0,
alphas = FALSE,
labels = FALSE,
round = FALSE,
...
)
x |
An object of class "feature" |
dataset |
Set the regular covariates as columns in a dataset |
fixed |
How many of the first columns in dataset are fixed and do not contribute to variable selection |
alphas |
Print a "?" instead of actual alphas to prepare the output for alpha estimation |
labels |
Should the covariates be named, or just referred to as their place in the data.frame. |
round |
Should numbers be rounded when printing? Default is FALSE, otherwise it can be set to the number of decimal places. |
... |
Not used. |
String representation of a feature
result <- gmjmcmc(x = matrix(rnorm(600), 100),
y = matrix(rnorm(100), 100),
P = 2,
transforms = c("p0", "exp_dbl"))
print(result$populations[[1]][1])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.