| rmclapply | R Documentation |
This function applies a function in parallel to a list or vector (X) using multiple cores.
On Linux/macOS, it uses mclapply, while on Windows it uses a hackish version of parallelism.
The Windows version is based on parLapply to mimic forking following Nathan VanHoudnos.
rmclapply(runs, args, fun, mc.cores = NULL)
runs |
The runs to run |
args |
The arguments to pass to fun |
fun |
The function to run |
mc.cores |
Number of cores to use for parallel processing. Defaults to |
A list of results, with one element for each element of X.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.