| set.transforms | R Documentation |
Set the transformations option for GMJMCMC (Genetically Modified MJMCMC), this is also done when running the algorithm, but this function allows for it to be done manually.
set.transforms(transforms)
transforms |
The vector of non-linear transformations |
No return value, just sets the gmjmcmc-transformations option
set.transforms(c("p0","p1"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.