string.population: Function to get a character representation of a list of...

View source: R/results.R

string.populationR Documentation

Function to get a character representation of a list of features

Description

Function to get a character representation of a list of features

Usage

string.population(x, round = 2)

Arguments

x

A list of feature objects

round

Rounding precision for parameters of the features

Value

A matrix of character representations of the features of a model.

Examples

result <- gmjmcmc(y = matrix(rnorm(100), 100),
x = matrix(rnorm(600), 100), 
P = 2, 
transforms = c("p0", "exp_dbl"))
string.population(result$populations[[1]])


FBMS documentation built on Sept. 13, 2025, 1:09 a.m.