summary.gmjmcmc_merged: Function to Print a Quick Summary of the Results
Description
Function to Print a Quick Summary of the Results
Usage
# S3 method for gmjmcmc_merged
summary(
object,
tol = 1e-04,
labels = FALSE,
effects = NULL,
pop = NULL,
data = NULL,
verbose = TRUE,
...
)
Value
A data frame containing the following columns:
feats.strings
Character representation of the features ordered by marginal probabilities.
marg.probs
Marginal probabilities corresponding to the ordered feature strings.
Arguments
object
The results to use
tol
The tolerance to use as a threshold when reporting the results.
labels
Should the covariates be named, or just referred to as their place in the data.frame.
effects
Quantiles for posterior modes of the effects across models to be reported, if either effects are NULL or if labels are NULL, no effects are reported.
pop
If null same as in merge.options for running parallel gmjmcmc otherwise results will be re-merged according to pop that can be "all", "last", "best" or "highest_mass"
data
Data to merge on, important if pre-filtering was used
verbose
If the summary should be printed to the console or just returned, defaults to TRUE