| log_prior | R Documentation |
Log model prior function
log_prior(mlpost_params, complex)
mlpost_params |
list of passed parameters of the likelihood in GMJMCMC |
complex |
list of complexity measures of the features included into the model |
A numeric with the log model prior.
log_prior(mlpost_params = list(r=2), complex = list(oc = 2))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.