Learn R Programming

FBMS (version 1.4)

model.string: Function to Generate a Function String for a Model Consisting of Features

Description

Function to Generate a Function String for a Model Consisting of Features

Usage

model.string(model, features, link = "I", round = 2)

Value

A character representation of a model

Arguments

model

A logical vector indicating which features to include

features

The population of features

link

The link function to use, as a string

round

Rounding error for the features in the printed format

Examples

Run this code
result <- gmjmcmc(
  y = matrix(rnorm(100), 100),
  x = matrix(rnorm(600), 100),
  P = 2, transforms = c("p0", "exp_dbl")
)
summary(result)
plot(result)
model.string(c(TRUE, FALSE, TRUE, FALSE, TRUE), result$populations[[1]])
model.string(result$models[[1]][1][[1]]$model, result$populations[[1]])

Run the code above in your browser using DataLab