powered by
Function to Plot GMJMCMC Results and Merged Results from merge.results
# S3 method for gmjmcmc plot(x, count = "all", pop = "best", tol = 1e-07, data = NULL, ...)
No return value, just creates a plot
The results to use
The number of features to plot, defaults to all
The population to plot, can be "last", "best" or "highest_mass". Defaults to "best".
The tolerance to use for the correlation when finding equivalent features, default is 0.0000001
Data to merge on, important if pre-filtering was used
Not used.
result <- gmjmcmc( y = matrix(rnorm(100), 100), x = matrix(rnorm(600), 100), P = 2, transforms = c("p0", "exp_dbl") ) plot(result)
Run the code above in your browser using DataLab