| string.population | R Documentation |
Function to get a character representation of a list of features
string.population(x, round = 2)
x |
A list of feature objects |
round |
Rounding precision for parameters of the features |
A matrix of character representations of the features of a model.
result <- gmjmcmc(y = matrix(rnorm(100), 100),
x = matrix(rnorm(600), 100),
P = 2,
transforms = c("p0", "exp_dbl"))
string.population(result$populations[[1]])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.