Learn R Programming

FBMS (version 1.4)

string.population: Function to Get a Character Representation of a List of Features

Description

Function to Get a Character Representation of a List of Features

Usage

string.population(x, round = 2)

Value

A matrix of character representations of the features of a model.

Arguments

x

A list of feature objects

round

Rounding precision for parameters of the features

Examples

Run this code
result <- gmjmcmc(
  y = matrix(rnorm(100), 100),
  x = matrix(rnorm(600), 100),
  P = 2,
  transforms = c("p0", "exp_dbl")
)
string.population(result$populations[[1]])

Run the code above in your browser using DataLab